.editorconfig
.htaccess
.htaccess.sample
.php-cs-fixer.dist.php
.user.ini
CHANGELOG.md
COPYING.txt
Gruntfile.js.sample
LICENSE.txt
LICENSE_AFL.txt
SECURITY.md
app
auth.json.sample
bin
composer.json
composer.lock
dev
generated
grunt-config.json.sample
lib
nginx.conf.sample
package.json.sample
phpserver
pub
setup
var
vendor